pub fn block_implied_type(block: &Block) -> Result<CtyType, SchemaError>Expand description
The implied cty object type of a resource / provider / data-source
Block — attributes plus nested blocks, in a single object type.
pub fn block_implied_type(block: &Block) -> Result<CtyType, SchemaError>The implied cty object type of a resource / provider / data-source
Block — attributes plus nested blocks, in a single object type.